#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QDebug>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    serialPort = new QSerialPort(this);

    // 初始化默认值
    ui->edit7->setText("3");
    ui->check1->setChecked(true);
    ui->check2->setChecked(true);
    ui->edit1->setText("1000");
    ui->edit2->setText("0");
    ui->edit3->setText("0");
    ui->edit4->setText("1000");
    ui->edit5->setText("0");
    ui->edit6->setText("0");
    ui->edit9->setText("100");

    // 初始化串口列表和波特率列表
    initSerialPortList();
    initBaudRateList();

    // 连接信号和槽
    connect(ui->edit1, &QLineEdit::textChanged, this, &MainWindow::on_getCh0Freq);
    connect(ui->edit2, &QLineEdit::textChanged, this, &MainWindow::on_getCh0Pha);
    connect(ui->edit3, &QLineEdit::textChanged, this, &MainWindow::on_getCh0AMP);
    connect(ui->edit4, &QLineEdit::textChanged, this, &MainWindow::on_getCh1Freq);
    connect(ui->edit5, &QLineEdit::textChanged, this, &MainWindow::on_getCh1Pha);
    connect(ui->edit6, &QLineEdit::textChanged, this, &MainWindow::on_getCh1AMP);
    connect(ui->button20, &QPushButton::clicked, this, &MainWindow::on_INTR);
    connect(ui->button3, &QPushButton::clicked, this, &MainWindow::on_CH0_EN);
    connect(ui->button4, &QPushButton::clicked, this, &MainWindow::on_CH1_ON);
    connect(ui->edit7, &QLineEdit::textChanged, this, &MainWindow::on_changeEdit7);
    connect(ui->button22, &QPushButton::clicked, this, &MainWindow::on_connectDevice);
    connect(ui->edit9, &QLineEdit::textChanged, this, &MainWindow::on_getFclk);
    connect(ui->check1, &QCheckBox::clicked, this, &MainWindow::on_CH0_OF);
    connect(ui->check2, &QCheckBox::clicked, this, &MainWindow::on_CH1_OF);
    connect(ui->buttonSync, &QPushButton::clicked, this, &MainWindow::on_buttonSync);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::initSerialPortList()
{
    // 清空下拉框
    ui->comboBoxSerialPort->clear();

    // 获取所有可用的串口信息
    QList<QSerialPortInfo> serialPortInfos = QSerialPortInfo::availablePorts();

    // 将可用的串口添加到下拉框中
    foreach (const QSerialPortInfo &info, serialPortInfos) {
        ui->comboBoxSerialPort->addItem(info.portName());
    }
}

void MainWindow::initBaudRateList()
{
    // 清空下拉框
    ui->comboBoxBaudRate->clear();

    // 定义常用的波特率列表
    QList<qint32> baudRates = {
        QSerialPort::Baud1200,
        QSerialPort::Baud2400,
        QSerialPort::Baud4800,
        QSerialPort::Baud9600,
        QSerialPort::Baud19200,
        QSerialPort::Baud38400,
        QSerialPort::Baud57600,
        QSerialPort::Baud115200
    };

    // 将波特率添加到下拉框中
    foreach (qint32 baudRate, baudRates) {
        ui->comboBoxBaudRate->addItem(QString::number(baudRate), baudRate);
    }

    // 设置默认波特率
    ui->comboBoxBaudRate->setCurrentText(QString::number(QSerialPort::Baud9600));
}

void MainWindow::on_getCh0Freq()
{
    QString text = ui->edit1->text();
    bool ok;
    quint64 freq = text.toULongLong(&ok);
    if (ok) {
        // 处理CH0频率
        qDebug() << "CH0 Freq: " << freq;
    }
}

void MainWindow::on_getCh0Pha()
{
    QString text = ui->edit2->text();
    bool ok;
    qint64 pha = text.toLongLong(&ok);
    if (ok) {
        // 处理CH0相位
        qDebug() << "CH0 Pha: " << pha;
    }
}

void MainWindow::on_getCh0AMP()
{
    QString text = ui->edit3->text();
    bool ok;
    qint64 amp = text.toLongLong(&ok);
    if (ok) {
        // 处理CH0幅度
        qDebug() << "CH0 AMP: " << amp;
    }
}

void MainWindow::on_getCh1Freq()
{
    QString text = ui->edit4->text();
    bool ok;
    qint64 freq = text.toLongLong(&ok);
    if (ok) {
        // 处理CH1频率
        qDebug() << "CH1 Freq: " << freq;
    }
}

void MainWindow::on_getCh1Pha()
{
    QString text = ui->edit5->text();
    bool ok;
    qint64 pha = text.toLongLong(&ok);
    if (ok) {
        // 处理CH1相位
        qDebug() << "CH1 Pha: " << pha;
    }
}

void MainWindow::on_getCh1AMP()
{
    QString text = ui->edit6->text();
    bool ok;
    qint64 amp = text.toLongLong(&ok);
    if (ok) {
        // 处理CH1幅度
        qDebug() << "CH1 AMP: " << amp;
    }
}

void MainWindow::on_INTR()
{
    // 处理INTR事件
    qDebug() << "INTR button clicked";
}

void MainWindow::on_CH0_EN()
{
    // 处理CH0使能事件
    qDebug() << "CH0 EN button clicked";
}

void MainWindow::on_CH1_ON()
{
    // 处理CH1开启事件
    qDebug() << "CH1 ON button clicked";
}

void MainWindow::on_changeEdit7()
{
    QString text = ui->edit7->text();
    bool ok;
    quint64 comNum = text.toULongLong(&ok);
    if (ok) {
        // 处理COM端口号
        qDebug() << "COM Num: " << comNum;
    }
}

void MainWindow::on_connectDevice()
{
    // 获取下拉框选择的串口和波特率
    QString portName = ui->comboBoxSerialPort->currentText();
    qint32 baudRate = ui->comboBoxBaudRate->currentData().toInt();

    serialPort->setPortName(portName);
    serialPort->setBaudRate(baudRate);
    serialPort->setDataBits(QSerialPort::Data8);
    serialPort->setParity(QSerialPort::NoParity);
    serialPort->setStopBits(QSerialPort::OneStop);
    serialPort->setFlowControl(QSerialPort::NoFlowControl);

    if (serialPort->open(QIODevice::ReadWrite)) {
        qDebug() << "Device connected";
    } else {
        qDebug() << "Failed to connect device";
    }
}

void MainWindow::on_getFclk()
{
    QString text = ui->edit9->text();
    bool ok;
    quint64 fclk = text.toULongLong(&ok);
    if (ok) {
        // 处理Fclk
        qDebug() << "Fclk: " << fclk;
    }
}

void MainWindow::on_CH0_OF()
{
    bool checked = ui->check1->isChecked();
    // 处理CH0开关事件
    qDebug() << "CH0 OF checkbox state: " << checked;
}

void MainWindow::on_CH1_OF()
{
    bool checked = ui->check2->isChecked();
    // 处理CH1开关事件
    qDebug() << "CH1 OF checkbox state: " << checked;
}

void MainWindow::on_buttonSync()
{
    // 处理同步按钮事件
    qDebug() << "Sync button clicked";
}
